lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite for Android: free password hash cracker in your pocket
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:   Tue, 25 Oct 2022 23:37:08 +0000
From:   Tanjuate Brunostar <tanjubrunostar0@...il.com>
To:     gregkh@...uxfoundation.org
Cc:     linux-staging@...ts.linux.dev, linux-kernel@...r.kernel.org,
        outreachy@...ts.linux.dev,
        Tanjuate Brunostar <tanjubrunostar0@...il.com>
Subject: [PATCH 12/17] staging: vt6655: changed variable name: cbFrameSize

change variable names cbFrameSize to meet the
linux coding standard, as it says to avoid using camelCase naming
style. Cought by checkpatch

Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@...il.com>
---
 drivers/staging/vt6655/rxtx.c | 58 +++++++++++++++++++----------------
 1 file changed, 31 insertions(+), 27 deletions(-)

diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index 819080b14d5d..cc3b642ef8af 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -101,7 +101,7 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 				     void *pv_rrv_time,
 				     void *pv_rts,
 				     void *pv_cts,
-				     unsigned int	cbFrameSize,
+				     unsigned int	cb_frame_size,
 				     bool bNeedACK,
 				     unsigned int	uDMAIdx,
 				     void *psEthHeader,
@@ -926,7 +926,7 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
  *      pv_rrv_time        - pv_rrv_time
  *      pv_rts            - RTS Buffer
  *      pCTS            - CTS Buffer
  *      cbFrameSize     - Transmit Data Length (Hdr+Payload+FCS)
  *      bNeedACK        - If need ACK
  *      uDescIdx        - Desc Index
  *  Out:
@@ -935,7 +935,7 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
  * Return Value: none
  *
  -
- * unsigned int cbFrameSize, Hdr+Payload+FCS
+ * unsigned int cb_frame_size, Hdr+Payload+FCS
  */
 static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 				     unsigned char by_pkt_type,
@@ -943,7 +943,7 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 				     void *pv_rrv_time,
 				     void *pv_rts,
 				     void *pv_cts,
-				     unsigned int cbFrameSize,
+				     unsigned int cb_frame_size,
 				     bool bNeedACK,
 				     unsigned int uDMAIdx,
 				     void *psEthHeader,
@@ -972,68 +972,72 @@ static void s_vgenerate_tx_parameter(struct vnt_private *p_device,
 			struct vnt_rrv_time_rts *buf = pv_rrv_time;
 
 			buf->rts_rrv_time_aa = get_rtscts_time(p_device, 2, by_pkt_type,
-							       cbFrameSize, wCurrentRate);
+							       cb_frame_size, wCurrentRate);
 			buf->rts_rrv_time_ba = get_rtscts_time(p_device, 1, by_pkt_type,
-							       cbFrameSize, wCurrentRate);
+							       cb_frame_size, wCurrentRate);
 			buf->rts_rrv_time_bb = get_rtscts_time(p_device, 0, by_pkt_type,
-							       cbFrameSize, wCurrentRate);
-			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type, cbFrameSize,
+							       cb_frame_size, wCurrentRate);
+			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type,
+								cb_frame_size,
 								wCurrentRate, bNeedACK);
-			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cbFrameSize,
+			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B,
+								cb_frame_size,
 								p_device->byTopCCKBasicRate,
 								bNeedACK);
 
-			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cbFrameSize, bNeedACK,
+			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, bNeedACK,
 					  b_dis_crc, psEthHeader, wCurrentRate, by_fb_option);
 		} else {/* RTS_needless, PCF mode */
 			struct vnt_rrv_time_cts *buf = pv_rrv_time;
 
-			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type, cbFrameSize,
+			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type,
+								cb_frame_size,
 								wCurrentRate, bNeedACK);
-			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cbFrameSize,
+			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B,
+								cb_frame_size,
 								p_device->byTopCCKBasicRate,
 								bNeedACK);
 			buf->cts_rrv_time_ba = get_rtscts_time(p_device, 3, by_pkt_type,
-							       cbFrameSize, wCurrentRate);
+							       cb_frame_size, wCurrentRate);
 
 			/* Fill CTS */
-			s_vFillCTSHead(p_device, uDMAIdx, by_pkt_type, pv_cts, cbFrameSize,
+			s_vFillCTSHead(p_device, uDMAIdx, by_pkt_type, pv_cts, cb_frame_size,
 				       bNeedACK, b_dis_crc, wCurrentRate, by_fb_option);
 		}
 	} else if (by_pkt_type == PK_TYPE_11A) {
 		if (pv_rts) {/* RTS_need, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pv_rrv_time;
 
-			buf->rts_rrv_time = get_rtscts_time(p_device, 2, by_pkt_type, cbFrameSize,
+			buf->rts_rrv_time = get_rtscts_time(p_device, 2, by_pkt_type, cb_frame_size,
 							    wCurrentRate);
-			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type, cbFrameSize,
+			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, by_pkt_type, cb_frame_size,
 							      wCurrentRate, bNeedACK);
 
 			/* Fill RTS */
-			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cbFrameSize, bNeedACK,
+			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, bNeedACK,
 					  b_dis_crc, psEthHeader, wCurrentRate, by_fb_option);
 		} else if (!pv_rts) {/* RTS_needless, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pv_rrv_time;
 
-			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11A, cbFrameSize,
+			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11A, cb_frame_size,
 							      wCurrentRate, bNeedACK);
 		}
 	} else if (by_pkt_type == PK_TYPE_11B) {
 		if (pv_rts) {/* RTS_need, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pv_rrv_time;
 
-			buf->rts_rrv_time = get_rtscts_time(p_device, 0, by_pkt_type, cbFrameSize,
+			buf->rts_rrv_time = get_rtscts_time(p_device, 0, by_pkt_type, cb_frame_size,
 							    wCurrentRate);
-			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cbFrameSize,
+			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cb_frame_size,
 							      wCurrentRate, bNeedACK);
 
 			/* Fill RTS */
-			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cbFrameSize, bNeedACK,
+			s_v_fill_rts_head(p_device, by_pkt_type, pv_rts, cb_frame_size, bNeedACK,
 					  b_dis_crc, psEthHeader, wCurrentRate, by_fb_option);
 		} else { /* RTS_needless, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pv_rrv_time;
 
-			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cbFrameSize,
+			buf->rrv_time = vnt_rxtx_rsvtime_le16(p_device, PK_TYPE_11B, cb_frame_size,
 							      wCurrentRate, bNeedACK);
 		}
 	}
@@ -1053,7 +1057,7 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 	struct vnt_tx_fifo_head *tx_buffer_head =
 			(struct vnt_tx_fifo_head *)td_info->buf;
 	u16 fifo_ctl = le16_to_cpu(tx_buffer_head->fifo_ctl);
-	unsigned int cbFrameSize;
+	unsigned int cb_frame_size;
 	__le16 uDuration;
 	unsigned char *pbyBuffer;
 	unsigned int uLength = 0;
@@ -1073,7 +1077,7 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 	unsigned short wTxBufSize;   /* FFinfo size */
 	unsigned char by_fb_option = AUTO_FB_NONE;
 
-	cbFrameSize = skb->len + 4;
+	cb_frame_size = skb->len + 4;
 
 	if (info->control.hw_key) {
 		switch (info->control.hw_key->cipher) {
@@ -1084,7 +1088,7 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 			break;
 		}
 
-		cbFrameSize += info->control.hw_key->icv_len;
+		cb_frame_size += info->control.hw_key->icv_len;
 
 		if (p_device->local_id > REV_ID_VT3253_A1) {
 			/* MAC Header should be padding 0 to DW alignment. */
@@ -1225,9 +1229,9 @@ static unsigned int s_cbFillTxBufHead(struct vnt_private *p_device,
 
 	/* Fill FIFO,RrvTime,RTS,and CTS */
 	s_vgenerate_tx_parameter(p_device, by_pkt_type, tx_buffer_head, pv_rrv_time, pv_rts, pv_cts,
-				 cbFrameSize, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
+				 cb_frame_size, bNeedACK, uDMAIdx, hdr, p_device->wCurrentRate);
 	/* Fill DataHead */
-	uDuration = s_uFillDataHead(p_device, by_pkt_type, pvTxDataHd, cbFrameSize, uDMAIdx,
+	uDuration = s_uFillDataHead(p_device, by_pkt_type, pvTxDataHd, cb_frame_size, uDMAIdx,
 				    bNeedACK, 0, 0, uMACfragNum, by_fb_option,
 				    p_device->wCurrentRate, is_pspoll);
 
@@ -926,7 +926,7 @@ static void s_vFillCTSHead(struct vnt_private *p_device,
  *      pv_rts            - RTS Buffer
  *      pCTS            - CTS Buffer
- *      cbFrameSize     - Transmit Data Length (Hdr+Payload+FCS)
+ *      cb_frame_size     - Transmit Data Length (Hdr+Payload+FCS)
  *      bNeedACK        - If need ACK
  *      uDescIdx        - Desc Index
-- 
2.34.1

Powered by blists - more mailing lists